summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorNicolas Norvez <norvez@chromium.org>2019-02-21 18:55:33 -0800
committerchrome-bot <chrome-bot@chromium.org>2019-02-27 13:43:48 -0800
commitbd90bed8c6670dd481f1b67a75dae03b6d284758 (patch)
tree554121cd77aa523f592378e435785bd339024b96
parenta8db8e8f7bed310a91cde6b3e8b39583f5c75a9f (diff)
downloadchrome-ec-bd90bed8c6670dd481f1b67a75dae03b6d284758.tar.gz
stm32: spi: fix link to bug in comments
Wrong link makes it harder to find the issue at hand, fix the URL BRANCH=none BUG=b:35539666 TEST=none Change-Id: I71bb069c43e540d101cdb60d6fa6f5d4e90a4d13 Signed-off-by: Nicolas Norvez <norvez@chromium.org> Reviewed-on: https://chromium-review.googlesource.com/1481661 Reviewed-by: Daisuke Nojiri <dnojiri@chromium.org>
-rw-r--r--chip/stm32/spi.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/chip/stm32/spi.c b/chip/stm32/spi.c
index 2cf604891e..de10176c77 100644
--- a/chip/stm32/spi.c
+++ b/chip/stm32/spi.c
@@ -99,7 +99,7 @@ static const uint8_t out_preamble[4] = {
* times in order to make sure it actually stays at the repeating byte after DMA
* ends.
*
- * See crbug.com/31390
+ * See crosbug.com/p/31390
*/
#if defined(CHIP_FAMILY_STM32F0) || defined(CHIP_FAMILY_STM32L4)
#define EC_SPI_PAST_END_LENGTH 4
@@ -424,7 +424,7 @@ static void spi_send_response_packet(struct host_packet *pkt)
((uint8_t *)pkt->response)[pkt->response_size + 0] = EC_SPI_PAST_END;
#if defined(CHIP_FAMILY_STM32F0) || defined(CHIP_FAMILY_STM32L4)
/* Make sure we are going to be outputting it properly when the DMA
* ends due to the TX FIFO bug on the F0. See crbug.com/31390
*/
((uint8_t *)pkt->response)[pkt->response_size + 1] = EC_SPI_PAST_END;
((uint8_t *)pkt->response)[pkt->response_size + 2] = EC_SPI_PAST_END;
@@ -563,7 +563,7 @@ void spi_event(enum gpio_signal signal)
#ifdef CHIP_FAMILY_STM32F0
CPRINTS("WARNING: Protocol version 2 is not supported on the F0"
- " line due to crbug.com/31390");
+ " line due to crosbug.com/p/31390");
#endif
args.version = in_msg[0] - EC_CMD_VERSION0;
@@ -424,7 +424,7 @@ static void spi_send_response_packet(struct host_packet *pkt)
#if defined(CHIP_FAMILY_STM32F0) || defined(CHIP_FAMILY_STM32L4)
/* Make sure we are going to be outputting it properly when the DMA
- * ends due to the TX FIFO bug on the F0. See crbug.com/31390
+ * ends due to the TX FIFO bug on the F0. See crosbug.com/p/31390
*/
((uint8_t *)pkt->response)[pkt->response_size + 1] = EC_SPI_PAST_END;